summaryrefslogtreecommitdiffstats
path: root/libtdepim/collectingprocess.h
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim/collectingprocess.h')
-rw-r--r--libtdepim/collectingprocess.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libtdepim/collectingprocess.h b/libtdepim/collectingprocess.h
index 69550ddd..962fe15d 100644
--- a/libtdepim/collectingprocess.h
+++ b/libtdepim/collectingprocess.h
@@ -39,14 +39,14 @@
namespace KPIM {
/**
* @short An output collecting KProcess class.
*
* This class simplifies the usage of KProcess by collecting all output
* (stdout/stderr) of the process.
*
* @author Ingo Kloecker <kloecker@kde.org>
*/
-class KDE_EXPORT CollectingProcess : public KProcess {
+class KDE_EXPORT CollectingProcess : public TDEProcess {
Q_OBJECT
public:
@@ -64,8 +64,8 @@ public:
TQByteArray collectedStderr();
private slots:
- void slotReceivedStdout( KProcess *, char *, int );
- void slotReceivedStderr( KProcess *, char *, int );
+ void slotReceivedStdout( TDEProcess *, char *, int );
+ void slotReceivedStderr( TDEProcess *, char *, int );
private:
class Private;
@@ -39,14 +39,14 @@
namespace KPIM {
/**
- * @short An output collecting KProcess class.
+ * @short An output collecting TDEProcess class.
*
@@ -39,14 +39,14 @@
*
- * This class simplifies the usage of KProcess by collecting all output
+ * This class simplifies the usage of TDEProcess by collecting all output
* (stdout/stderr) of the process.
*